@@ -1395,7 +1395,7 @@ brasero_burn_dialog_activity_start (BraseroBurnDialog *dialog)
 	if (window) {
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (window, cursor);
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 	}
 
 	gtk_button_set_use_stock (GTK_BUTTON (priv->cancel), TRUE);
@@ -1483,7 +1483,7 @@ brasero_burn_dialog_install_missing_cb (BraseroBurn *burn,
 
 	/* Get the xid */
 	window = gtk_widget_get_window (user_data);
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (window));
+	xid = gdk_x11_window_get_xid (window);
 
 	package = brasero_pk_new ();
 	cancel = g_cancellable_new ();
