@@ -29,16 +29,18 @@
 
 #include <gtk/gtk.h>
 
-#include "brasero-split-dialog.h"
-#include "brasero-player.h"
-#include "brasero-utils.h"
+#include "brasero-misc.h"
 #include "brasero-metadata.h"
 
-#include "brasero-misc.h"
+#include "brasero-units.h"
 
 #include "brasero-track.h"
 #include "brasero-track-stream.h"
 
+#include "brasero-split-dialog.h"
+#include "brasero-song-control.h"
+#include "brasero-utils.h"
+
 enum {
 	START_COL,
 	END_COL,
@@ -83,12 +85,15 @@ G_DEFINE_TYPE (BraseroSplitDialog, brasero_split_dialog, GTK_TYPE_DIALOG);
 
 void
 brasero_split_dialog_set_uri (BraseroSplitDialog *self,
-			      const gchar *uri)
+			      const gchar *uri,
+                              const gchar *title,
+                              const gchar *artist)
 {
 	BraseroSplitDialogPrivate *priv;
 
 	priv = BRASERO_SPLIT_DIALOG_PRIVATE (self);
-	brasero_player_set_uri (BRASERO_PLAYER (priv->player), uri);
+	brasero_song_control_set_uri (BRASERO_SONG_CONTROL (priv->player), uri);
+	brasero_song_control_set_info (BRASERO_SONG_CONTROL (priv->player), title, artist);
 }
 
 void
@@ -112,9 +117,9 @@ brasero_split_dialog_set_boundaries (BraseroSplitDialog *self,
 	priv->start = start;
 	priv->end = end;
 
-	brasero_player_set_boundaries (BRASERO_PLAYER (priv->player),
-				       priv->start,
-				       priv->end);
+	brasero_song_control_set_boundaries (BRASERO_SONG_CONTROL (priv->player),
+	                                     priv->start,
+	                                     priv->end);
 }
 
 GSList *
@@ -209,7 +214,7 @@ brasero_split_dialog_cut (BraseroSplitDialog *self,
 
 		/* nothing in the tree yet */
 		if (priv->end <= 0)
-			end = brasero_player_get_length (BRASERO_PLAYER (priv->player));
+			end = brasero_song_control_get_length (BRASERO_SONG_CONTROL (priv->player));
 		else
 			end = priv->end;
 
@@ -619,7 +624,7 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 
 	if (error) {
 		brasero_utils_message_dialog (GTK_WIDGET (self),
-					      _("An error occured while detecting silences."),
+					      _("An error occurred while detecting silences."),
 					      error->message,
 					      GTK_MESSAGE_ERROR);
 		return;
@@ -731,7 +736,7 @@ brasero_split_dialog_cut_clicked_cb (GtkButton *button,
 		gint64 pos;
 
 		/* this one is before since it doesn't wipe all slices */
-		pos = brasero_player_get_pos (BRASERO_PLAYER (priv->player));
+		pos = brasero_song_control_get_pos (BRASERO_SONG_CONTROL (priv->player));
 		brasero_split_dialog_cut (self, pos + priv->start, TRUE);
 		return;
 	}
@@ -796,7 +801,7 @@ brasero_split_dialog_cut_clicked_cb (GtkButton *button,
 			  G_CALLBACK (brasero_split_dialog_metadata_finished_cb),
 			  self);
 	brasero_metadata_get_info_async (priv->metadata,
-					 brasero_player_get_uri (BRASERO_PLAYER (priv->player)),
+					 brasero_song_control_get_uri (BRASERO_SONG_CONTROL (priv->player)),
 					 BRASERO_METADATA_FLAG_SILENCES);
 
 	/* stop anything from playing and grey out things */
@@ -1048,12 +1053,10 @@ brasero_split_dialog_init (BraseroSplitDialog *object)
 	gtk_window_set_title (GTK_WINDOW (object), _("Split Track"));
 	gtk_window_set_default_size (GTK_WINDOW (object), 500, 600);
 
-	gtk_dialog_set_has_separator (GTK_DIALOG (object), FALSE);
-
 	gtk_dialog_add_button (GTK_DIALOG (object), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (object), GTK_STOCK_OK, GTK_RESPONSE_OK);
 
-	vbox = GTK_DIALOG (object)->vbox;
+	vbox = gtk_dialog_get_content_area (GTK_DIALOG (object));
 	gtk_box_set_spacing (GTK_BOX (vbox), 0);
 
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
@@ -1062,7 +1065,7 @@ brasero_split_dialog_init (BraseroSplitDialog *object)
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_widget_show (hbox);
 
-	priv->combo = gtk_combo_box_new_text ();
+	priv->combo = gtk_combo_box_text_new ();
 
 	label = gtk_label_new_with_mnemonic (_("M_ethod:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -1073,10 +1076,10 @@ brasero_split_dialog_init (BraseroSplitDialog *object)
 	gtk_widget_set_tooltip_text (priv->combo, _("Method to be used to split the track"));
 	gtk_widget_show (priv->combo);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->combo, TRUE, TRUE, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Split track manually"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Split track in parts with a fixed length"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Split track in a fixed number of parts"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->combo), _("Split track for each silence"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->combo), _("Split track manually"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->combo), _("Split track in parts with a fixed length"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->combo), _("Split track in a fixed number of parts"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->combo), _("Split track for each silence"));
 	g_signal_connect (priv->combo,
 			  "changed",
 			  G_CALLBACK (brasero_split_dialog_combo_changed_cb),
@@ -1101,7 +1104,7 @@ brasero_split_dialog_init (BraseroSplitDialog *object)
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (priv->notebook), FALSE);
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->notebook), FALSE);
 
-	priv->player = brasero_player_new ();
+	priv->player = brasero_song_control_new ();
 	gtk_widget_show (priv->player);
 	gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), priv->player, NULL);
 
